import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface ImageConfig extends cdktf.TerraformMetaArguments {
    /**
     * If true, then the image is removed forcibly when the resource is destroyed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/image.html#force_remove Image#force_remove}
     *
     * @stability stable
     */
    readonly forceRemove?: boolean | cdktf.IResolvable;
    /**
     * If true, then the Docker image won't be deleted on destroy operation.
     *
     * If this is false, it will delete the image from the docker local storage on destroy operation.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/image.html#keep_locally Image#keep_locally}
     *
     * @stability stable
     */
    readonly keepLocally?: boolean | cdktf.IResolvable;
    /**
     * The name of the Docker image, including any tags or SHA256 repo digests.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/image.html#name Image#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * A value which cause an image pull when changed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/image.html#pull_trigger Image#pull_trigger}
     *
     * @stability stable
     */
    readonly pullTrigger?: string;
    /**
     * List of values which cause an image pull when changed.
     *
     * This is used to store the image digest from the registry when using the [docker_registry_image](../data-sources/registry_image.md).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/image.html#pull_triggers Image#pull_triggers}
     *
     * @stability stable
     */
    readonly pullTriggers?: string[];
    /**
     * build block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/image.html#build Image#build}
     *
     * @stability stable
     */
    readonly buildAttribute?: ImageBuild;
}
/**
 * @stability stable
 */
export interface ImageBuild {
    /**
     * Set build-time variables.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/image.html#build_arg Image#build_arg}
     *
     * @stability stable
     */
    readonly buildArg?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Name of the Dockerfile. Defaults to `Dockerfile`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/image.html#dockerfile Image#dockerfile}
     *
     * @stability stable
     */
    readonly dockerfile?: string;
    /**
     * Always remove intermediate containers.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/image.html#force_remove Image#force_remove}
     *
     * @stability stable
     */
    readonly forceRemove?: boolean | cdktf.IResolvable;
    /**
     * Set metadata for an image.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/image.html#label Image#label}
     *
     * @stability stable
     */
    readonly label?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Do not use cache when building the image.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/image.html#no_cache Image#no_cache}
     *
     * @stability stable
     */
    readonly noCache?: boolean | cdktf.IResolvable;
    /**
     * Context path.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/image.html#path Image#path}
     *
     * @stability stable
     */
    readonly path: string;
    /**
     * Remove intermediate containers after a successful build. Defaults to  `true`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/image.html#remove Image#remove}
     *
     * @stability stable
     */
    readonly remove?: boolean | cdktf.IResolvable;
    /**
     * Name and optionally a tag in the 'name:tag' format.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/image.html#tag Image#tag}
     *
     * @stability stable
     */
    readonly tag?: string[];
    /**
     * Set the target build stage to build.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/image.html#target Image#target}
     *
     * @stability stable
     */
    readonly target?: string;
}
export declare function imageBuildToTerraform(struct?: ImageBuildOutputReference | ImageBuild): any;
/**
 * @stability stable
 */
export declare class ImageBuildOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ImageBuild | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ImageBuild | undefined);
    private _buildArg?;
    /**
     * @stability stable
     */
    get buildArg(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set buildArg(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetBuildArg(): void;
    /**
     * @stability stable
     */
    get buildArgInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _dockerfile?;
    /**
     * @stability stable
     */
    get dockerfile(): string;
    /**
     * @stability stable
     */
    set dockerfile(value: string);
    /**
     * @stability stable
     */
    resetDockerfile(): void;
    /**
     * @stability stable
     */
    get dockerfileInput(): string | undefined;
    private _forceRemove?;
    /**
     * @stability stable
     */
    get forceRemove(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set forceRemove(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetForceRemove(): void;
    /**
     * @stability stable
     */
    get forceRemoveInput(): boolean | cdktf.IResolvable | undefined;
    private _label?;
    /**
     * @stability stable
     */
    get label(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set label(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetLabel(): void;
    /**
     * @stability stable
     */
    get labelInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _noCache?;
    /**
     * @stability stable
     */
    get noCache(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set noCache(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetNoCache(): void;
    /**
     * @stability stable
     */
    get noCacheInput(): boolean | cdktf.IResolvable | undefined;
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
    private _remove?;
    /**
     * @stability stable
     */
    get remove(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set remove(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetRemove(): void;
    /**
     * @stability stable
     */
    get removeInput(): boolean | cdktf.IResolvable | undefined;
    private _tag?;
    /**
     * @stability stable
     */
    get tag(): string[];
    /**
     * @stability stable
     */
    set tag(value: string[]);
    /**
     * @stability stable
     */
    resetTag(): void;
    /**
     * @stability stable
     */
    get tagInput(): string[] | undefined;
    private _target?;
    /**
     * @stability stable
     */
    get target(): string;
    /**
     * @stability stable
     */
    set target(value: string);
    /**
     * @stability stable
     */
    resetTarget(): void;
    /**
     * @stability stable
     */
    get targetInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/docker/r/image.html docker_image}.
 *
 * @stability stable
 */
export declare class Image extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/docker/r/image.html docker_image} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ImageConfig);
    private _forceRemove?;
    /**
     * @stability stable
     */
    get forceRemove(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set forceRemove(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetForceRemove(): void;
    /**
     * @stability stable
     */
    get forceRemoveInput(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _keepLocally?;
    /**
     * @stability stable
     */
    get keepLocally(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set keepLocally(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetKeepLocally(): void;
    /**
     * @stability stable
     */
    get keepLocallyInput(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    get latest(): string;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    /**
     * @stability stable
     */
    get output(): string;
    private _pullTrigger?;
    /**
     * @stability stable
     */
    get pullTrigger(): string;
    /**
     * @stability stable
     */
    set pullTrigger(value: string);
    /**
     * @stability stable
     */
    resetPullTrigger(): void;
    /**
     * @stability stable
     */
    get pullTriggerInput(): string | undefined;
    private _pullTriggers?;
    /**
     * @stability stable
     */
    get pullTriggers(): string[];
    /**
     * @stability stable
     */
    set pullTriggers(value: string[]);
    /**
     * @stability stable
     */
    resetPullTriggers(): void;
    /**
     * @stability stable
     */
    get pullTriggersInput(): string[] | undefined;
    /**
     * @stability stable
     */
    get repoDigest(): string;
    private _build;
    /**
     * @stability stable
     */
    get buildAttribute(): ImageBuildOutputReference;
    /**
     * @stability stable
     */
    putBuildAttribute(value: ImageBuild): void;
    /**
     * @stability stable
     */
    resetBuildAttribute(): void;
    /**
     * @stability stable
     */
    get buildAttributeInput(): ImageBuild | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
