import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface ServiceConfig extends cdktf.TerraformMetaArguments {
    /**
     * Name of the service.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#name Service#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * auth block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#auth Service#auth}
     *
     * @stability stable
     */
    readonly auth?: ServiceAuth;
    /**
     * converge_config block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#converge_config Service#converge_config}
     *
     * @stability stable
     */
    readonly convergeConfig?: ServiceConvergeConfig;
    /**
     * endpoint_spec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#endpoint_spec Service#endpoint_spec}
     *
     * @stability stable
     */
    readonly endpointSpec?: ServiceEndpointSpec;
    /**
     * labels block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#labels Service#labels}
     *
     * @stability stable
     */
    readonly labels?: ServiceLabels[];
    /**
     * mode block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#mode Service#mode}
     *
     * @stability stable
     */
    readonly mode?: ServiceMode;
    /**
     * rollback_config block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#rollback_config Service#rollback_config}
     *
     * @stability stable
     */
    readonly rollbackConfig?: ServiceRollbackConfig;
    /**
     * task_spec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#task_spec Service#task_spec}
     *
     * @stability stable
     */
    readonly taskSpec: ServiceTaskSpec;
    /**
     * update_config block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#update_config Service#update_config}
     *
     * @stability stable
     */
    readonly updateConfig?: ServiceUpdateConfig;
}
/**
 * @stability stable
 */
export interface ServiceAuth {
    /**
     * The password.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#password Service#password}
     *
     * @stability stable
     */
    readonly password?: string;
    /**
     * The address of the server for the authentication.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#server_address Service#server_address}
     *
     * @stability stable
     */
    readonly serverAddress: string;
    /**
     * The username.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#username Service#username}
     *
     * @stability stable
     */
    readonly username?: string;
}
export declare function serviceAuthToTerraform(struct?: ServiceAuthOutputReference | ServiceAuth): any;
/**
 * @stability stable
 */
export declare class ServiceAuthOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ServiceAuth | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ServiceAuth | undefined);
    private _password?;
    /**
     * @stability stable
     */
    get password(): string;
    /**
     * @stability stable
     */
    set password(value: string);
    /**
     * @stability stable
     */
    resetPassword(): void;
    /**
     * @stability stable
     */
    get passwordInput(): string | undefined;
    private _serverAddress?;
    /**
     * @stability stable
     */
    get serverAddress(): string;
    /**
     * @stability stable
     */
    set serverAddress(value: string);
    /**
     * @stability stable
     */
    get serverAddressInput(): string | undefined;
    private _username?;
    /**
     * @stability stable
     */
    get username(): string;
    /**
     * @stability stable
     */
    set username(value: string);
    /**
     * @stability stable
     */
    resetUsername(): void;
    /**
     * @stability stable
     */
    get usernameInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface ServiceConvergeConfig {
    /**
     * The interval to check if the desired state is reached (ms|s). Defaults to `7s`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#delay Service#delay}
     *
     * @stability stable
     */
    readonly delay?: string;
    /**
     * The timeout of the service to reach the desired state (s|m). Defaults to `3m`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#timeout Service#timeout}
     *
     * @stability stable
     */
    readonly timeout?: string;
}
export declare function serviceConvergeConfigToTerraform(struct?: ServiceConvergeConfigOutputReference | ServiceConvergeConfig): any;
/**
 * @stability stable
 */
export declare class ServiceConvergeConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ServiceConvergeConfig | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ServiceConvergeConfig | undefined);
    private _delay?;
    /**
     * @stability stable
     */
    get delay(): string;
    /**
     * @stability stable
     */
    set delay(value: string);
    /**
     * @stability stable
     */
    resetDelay(): void;
    /**
     * @stability stable
     */
    get delayInput(): string | undefined;
    private _timeout?;
    /**
     * @stability stable
     */
    get timeout(): string;
    /**
     * @stability stable
     */
    set timeout(value: string);
    /**
     * @stability stable
     */
    resetTimeout(): void;
    /**
     * @stability stable
     */
    get timeoutInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface ServiceEndpointSpecPorts {
    /**
     * A random name for the port.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#name Service#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Rrepresents the protocol of a port: 'tcp', 'udp' or 'sctp'. Defaults to `tcp`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#protocol Service#protocol}
     *
     * @stability stable
     */
    readonly protocol?: string;
    /**
     * Represents the mode in which the port is to be published: 'ingress' or 'host'. Defaults to `ingress`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#publish_mode Service#publish_mode}
     *
     * @stability stable
     */
    readonly publishMode?: string;
    /**
     * The port on the swarm hosts.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#published_port Service#published_port}
     *
     * @stability stable
     */
    readonly publishedPort?: number;
    /**
     * The port inside the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#target_port Service#target_port}
     *
     * @stability stable
     */
    readonly targetPort: number;
}
export declare function serviceEndpointSpecPortsToTerraform(struct?: ServiceEndpointSpecPorts): any;
/**
 * @stability stable
 */
export interface ServiceEndpointSpec {
    /**
     * The mode of resolution to use for internal load balancing between tasks.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#mode Service#mode}
     *
     * @stability stable
     */
    readonly mode?: string;
    /**
     * ports block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#ports Service#ports}
     *
     * @stability stable
     */
    readonly ports?: ServiceEndpointSpecPorts[];
}
export declare function serviceEndpointSpecToTerraform(struct?: ServiceEndpointSpecOutputReference | ServiceEndpointSpec): any;
/**
 * @stability stable
 */
export declare class ServiceEndpointSpecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ServiceEndpointSpec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ServiceEndpointSpec | undefined);
    private _mode?;
    /**
     * @stability stable
     */
    get mode(): string;
    /**
     * @stability stable
     */
    set mode(value: string);
    /**
     * @stability stable
     */
    resetMode(): void;
    /**
     * @stability stable
     */
    get modeInput(): string | undefined;
    private _ports?;
    /**
     * @stability stable
     */
    get ports(): ServiceEndpointSpecPorts[];
    /**
     * @stability stable
     */
    set ports(value: ServiceEndpointSpecPorts[]);
    /**
     * @stability stable
     */
    resetPorts(): void;
    /**
     * @stability stable
     */
    get portsInput(): ServiceEndpointSpecPorts[] | undefined;
}
/**
 * @stability stable
 */
export interface ServiceLabels {
    /**
     * Name of the label.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#label Service#label}
     *
     * @stability stable
     */
    readonly label: string;
    /**
     * Value of the label.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#value Service#value}
     *
     * @stability stable
     */
    readonly value: string;
}
export declare function serviceLabelsToTerraform(struct?: ServiceLabels): any;
/**
 * @stability stable
 */
export interface ServiceModeReplicated {
    /**
     * The amount of replicas of the service. Defaults to `1`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#replicas Service#replicas}
     *
     * @stability stable
     */
    readonly replicas?: number;
}
export declare function serviceModeReplicatedToTerraform(struct?: ServiceModeReplicatedOutputReference | ServiceModeReplicated): any;
/**
 * @stability stable
 */
export declare class ServiceModeReplicatedOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ServiceModeReplicated | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ServiceModeReplicated | undefined);
    private _replicas?;
    /**
     * @stability stable
     */
    get replicas(): number;
    /**
     * @stability stable
     */
    set replicas(value: number);
    /**
     * @stability stable
     */
    resetReplicas(): void;
    /**
     * @stability stable
     */
    get replicasInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface ServiceMode {
    /**
     * The global service mode. Defaults to `false`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#global Service#global}
     *
     * @stability stable
     */
    readonly global?: boolean | cdktf.IResolvable;
    /**
     * replicated block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#replicated Service#replicated}
     *
     * @stability stable
     */
    readonly replicated?: ServiceModeReplicated;
}
export declare function serviceModeToTerraform(struct?: ServiceModeOutputReference | ServiceMode): any;
/**
 * @stability stable
 */
export declare class ServiceModeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ServiceMode | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ServiceMode | undefined);
    private _global?;
    /**
     * @stability stable
     */
    get global(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set global(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetGlobal(): void;
    /**
     * @stability stable
     */
    get globalInput(): boolean | cdktf.IResolvable | undefined;
    private _replicated;
    /**
     * @stability stable
     */
    get replicated(): ServiceModeReplicatedOutputReference;
    /**
     * @stability stable
     */
    putReplicated(value: ServiceModeReplicated): void;
    /**
     * @stability stable
     */
    resetReplicated(): void;
    /**
     * @stability stable
     */
    get replicatedInput(): ServiceModeReplicated | undefined;
}
/**
 * @stability stable
 */
export interface ServiceRollbackConfig {
    /**
     * Delay between task rollbacks (ns|us|ms|s|m|h). Defaults to `0s`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#delay Service#delay}
     *
     * @stability stable
     */
    readonly delay?: string;
    /**
     * Action on rollback failure: pause | continue. Defaults to `pause`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#failure_action Service#failure_action}
     *
     * @stability stable
     */
    readonly failureAction?: string;
    /**
     * Failure rate to tolerate during a rollback. Defaults to `0.0`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#max_failure_ratio Service#max_failure_ratio}
     *
     * @stability stable
     */
    readonly maxFailureRatio?: string;
    /**
     * Duration after each task rollback to monitor for failure (ns|us|ms|s|m|h). Defaults to `5s`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#monitor Service#monitor}
     *
     * @stability stable
     */
    readonly monitor?: string;
    /**
     * Rollback order: either 'stop-first' or 'start-first'. Defaults to `stop-first`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#order Service#order}
     *
     * @stability stable
     */
    readonly order?: string;
    /**
     * Maximum number of tasks to be rollbacked in one iteration. Defaults to `1`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#parallelism Service#parallelism}
     *
     * @stability stable
     */
    readonly parallelism?: number;
}
export declare function serviceRollbackConfigToTerraform(struct?: ServiceRollbackConfigOutputReference | ServiceRollbackConfig): any;
/**
 * @stability stable
 */
export declare class ServiceRollbackConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ServiceRollbackConfig | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ServiceRollbackConfig | undefined);
    private _delay?;
    /**
     * @stability stable
     */
    get delay(): string;
    /**
     * @stability stable
     */
    set delay(value: string);
    /**
     * @stability stable
     */
    resetDelay(): void;
    /**
     * @stability stable
     */
    get delayInput(): string | undefined;
    private _failureAction?;
    /**
     * @stability stable
     */
    get failureAction(): string;
    /**
     * @stability stable
     */
    set failureAction(value: string);
    /**
     * @stability stable
     */
    resetFailureAction(): void;
    /**
     * @stability stable
     */
    get failureActionInput(): string | undefined;
    private _maxFailureRatio?;
    /**
     * @stability stable
     */
    get maxFailureRatio(): string;
    /**
     * @stability stable
     */
    set maxFailureRatio(value: string);
    /**
     * @stability stable
     */
    resetMaxFailureRatio(): void;
    /**
     * @stability stable
     */
    get maxFailureRatioInput(): string | undefined;
    private _monitor?;
    /**
     * @stability stable
     */
    get monitor(): string;
    /**
     * @stability stable
     */
    set monitor(value: string);
    /**
     * @stability stable
     */
    resetMonitor(): void;
    /**
     * @stability stable
     */
    get monitorInput(): string | undefined;
    private _order?;
    /**
     * @stability stable
     */
    get order(): string;
    /**
     * @stability stable
     */
    set order(value: string);
    /**
     * @stability stable
     */
    resetOrder(): void;
    /**
     * @stability stable
     */
    get orderInput(): string | undefined;
    private _parallelism?;
    /**
     * @stability stable
     */
    get parallelism(): number;
    /**
     * @stability stable
     */
    set parallelism(value: number);
    /**
     * @stability stable
     */
    resetParallelism(): void;
    /**
     * @stability stable
     */
    get parallelismInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface ServiceTaskSpecContainerSpecConfigs {
    /**
     * ID of the specific config that we're referencing.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#config_id Service#config_id}
     *
     * @stability stable
     */
    readonly configId: string;
    /**
     * Name of the config that this references, but this is just provided for lookup/display purposes.
     *
     * The config in the reference will be identified by its ID
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#config_name Service#config_name}
     *
     * @stability stable
     */
    readonly configName?: string;
    /**
     * Represents the file GID. Defaults to `0`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#file_gid Service#file_gid}
     *
     * @stability stable
     */
    readonly fileGid?: string;
    /**
     * Represents represents the FileMode of the file. Defaults to `0o444`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#file_mode Service#file_mode}
     *
     * @stability stable
     */
    readonly fileMode?: number;
    /**
     * Represents the final filename in the filesystem.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#file_name Service#file_name}
     *
     * @stability stable
     */
    readonly fileName: string;
    /**
     * Represents the file UID. Defaults to `0`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#file_uid Service#file_uid}
     *
     * @stability stable
     */
    readonly fileUid?: string;
}
export declare function serviceTaskSpecContainerSpecConfigsToTerraform(struct?: ServiceTaskSpecContainerSpecConfigs): any;
/**
 * @stability stable
 */
export interface ServiceTaskSpecContainerSpecDnsConfig {
    /**
     * The IP addresses of the name servers.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#nameservers Service#nameservers}
     *
     * @stability stable
     */
    readonly nameservers: string[];
    /**
     * A list of internal resolver variables to be modified (e.g., debug, ndots:3, etc.).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#options Service#options}
     *
     * @stability stable
     */
    readonly options?: string[];
    /**
     * A search list for host-name lookup.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#search Service#search}
     *
     * @stability stable
     */
    readonly search?: string[];
}
export declare function serviceTaskSpecContainerSpecDnsConfigToTerraform(struct?: ServiceTaskSpecContainerSpecDnsConfigOutputReference | ServiceTaskSpecContainerSpecDnsConfig): any;
/**
 * @stability stable
 */
export declare class ServiceTaskSpecContainerSpecDnsConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ServiceTaskSpecContainerSpecDnsConfig | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ServiceTaskSpecContainerSpecDnsConfig | undefined);
    private _nameservers?;
    /**
     * @stability stable
     */
    get nameservers(): string[];
    /**
     * @stability stable
     */
    set nameservers(value: string[]);
    /**
     * @stability stable
     */
    get nameserversInput(): string[] | undefined;
    private _options?;
    /**
     * @stability stable
     */
    get options(): string[];
    /**
     * @stability stable
     */
    set options(value: string[]);
    /**
     * @stability stable
     */
    resetOptions(): void;
    /**
     * @stability stable
     */
    get optionsInput(): string[] | undefined;
    private _search?;
    /**
     * @stability stable
     */
    get search(): string[];
    /**
     * @stability stable
     */
    set search(value: string[]);
    /**
     * @stability stable
     */
    resetSearch(): void;
    /**
     * @stability stable
     */
    get searchInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface ServiceTaskSpecContainerSpecHealthcheck {
    /**
     * Time between running the check (ms|s|m|h). Defaults to `0s`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#interval Service#interval}
     *
     * @stability stable
     */
    readonly interval?: string;
    /**
     * Consecutive failures needed to report unhealthy. Defaults to `0`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#retries Service#retries}
     *
     * @stability stable
     */
    readonly retries?: number;
    /**
     * Start period for the container to initialize before counting retries towards unstable (ms|s|m|h). Defaults to `0s`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#start_period Service#start_period}
     *
     * @stability stable
     */
    readonly startPeriod?: string;
    /**
     * The test to perform as list.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#test Service#test}
     *
     * @stability stable
     */
    readonly test: string[];
    /**
     * Maximum time to allow one check to run (ms|s|m|h). Defaults to `0s`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#timeout Service#timeout}
     *
     * @stability stable
     */
    readonly timeout?: string;
}
export declare function serviceTaskSpecContainerSpecHealthcheckToTerraform(struct?: ServiceTaskSpecContainerSpecHealthcheckOutputReference | ServiceTaskSpecContainerSpecHealthcheck): any;
/**
 * @stability stable
 */
export declare class ServiceTaskSpecContainerSpecHealthcheckOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ServiceTaskSpecContainerSpecHealthcheck | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ServiceTaskSpecContainerSpecHealthcheck | undefined);
    private _interval?;
    /**
     * @stability stable
     */
    get interval(): string;
    /**
     * @stability stable
     */
    set interval(value: string);
    /**
     * @stability stable
     */
    resetInterval(): void;
    /**
     * @stability stable
     */
    get intervalInput(): string | undefined;
    private _retries?;
    /**
     * @stability stable
     */
    get retries(): number;
    /**
     * @stability stable
     */
    set retries(value: number);
    /**
     * @stability stable
     */
    resetRetries(): void;
    /**
     * @stability stable
     */
    get retriesInput(): number | undefined;
    private _startPeriod?;
    /**
     * @stability stable
     */
    get startPeriod(): string;
    /**
     * @stability stable
     */
    set startPeriod(value: string);
    /**
     * @stability stable
     */
    resetStartPeriod(): void;
    /**
     * @stability stable
     */
    get startPeriodInput(): string | undefined;
    private _test?;
    /**
     * @stability stable
     */
    get test(): string[];
    /**
     * @stability stable
     */
    set test(value: string[]);
    /**
     * @stability stable
     */
    get testInput(): string[] | undefined;
    private _timeout?;
    /**
     * @stability stable
     */
    get timeout(): string;
    /**
     * @stability stable
     */
    set timeout(value: string);
    /**
     * @stability stable
     */
    resetTimeout(): void;
    /**
     * @stability stable
     */
    get timeoutInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface ServiceTaskSpecContainerSpecHosts {
    /**
     * The name of the host.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#host Service#host}
     *
     * @stability stable
     */
    readonly host: string;
    /**
     * The ip of the host.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#ip Service#ip}
     *
     * @stability stable
     */
    readonly ip: string;
}
export declare function serviceTaskSpecContainerSpecHostsToTerraform(struct?: ServiceTaskSpecContainerSpecHosts): any;
/**
 * @stability stable
 */
export interface ServiceTaskSpecContainerSpecLabels {
    /**
     * Name of the label.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#label Service#label}
     *
     * @stability stable
     */
    readonly label: string;
    /**
     * Value of the label.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#value Service#value}
     *
     * @stability stable
     */
    readonly value: string;
}
export declare function serviceTaskSpecContainerSpecLabelsToTerraform(struct?: ServiceTaskSpecContainerSpecLabels): any;
/**
 * @stability stable
 */
export interface ServiceTaskSpecContainerSpecMountsBindOptions {
    /**
     * Bind propagation refers to whether or not mounts created within a given bind-mount or named volume can be propagated to replicas of that mount.
     *
     * See the [docs](https://docs.docker.com/storage/bind-mounts/#configure-bind-propagation) for details. Defaults to `rprivate`
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#propagation Service#propagation}
     *
     * @stability stable
     */
    readonly propagation?: string;
}
export declare function serviceTaskSpecContainerSpecMountsBindOptionsToTerraform(struct?: ServiceTaskSpecContainerSpecMountsBindOptionsOutputReference | ServiceTaskSpecContainerSpecMountsBindOptions): any;
/**
 * @stability stable
 */
export declare class ServiceTaskSpecContainerSpecMountsBindOptionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ServiceTaskSpecContainerSpecMountsBindOptions | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ServiceTaskSpecContainerSpecMountsBindOptions | undefined);
    private _propagation?;
    /**
     * @stability stable
     */
    get propagation(): string;
    /**
     * @stability stable
     */
    set propagation(value: string);
    /**
     * @stability stable
     */
    resetPropagation(): void;
    /**
     * @stability stable
     */
    get propagationInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface ServiceTaskSpecContainerSpecMountsTmpfsOptions {
    /**
     * The permission mode for the tmpfs mount in an integer.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#mode Service#mode}
     *
     * @stability stable
     */
    readonly mode?: number;
    /**
     * The size for the tmpfs mount in bytes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#size_bytes Service#size_bytes}
     *
     * @stability stable
     */
    readonly sizeBytes?: number;
}
export declare function serviceTaskSpecContainerSpecMountsTmpfsOptionsToTerraform(struct?: ServiceTaskSpecContainerSpecMountsTmpfsOptionsOutputReference | ServiceTaskSpecContainerSpecMountsTmpfsOptions): any;
/**
 * @stability stable
 */
export declare class ServiceTaskSpecContainerSpecMountsTmpfsOptionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ServiceTaskSpecContainerSpecMountsTmpfsOptions | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ServiceTaskSpecContainerSpecMountsTmpfsOptions | undefined);
    private _mode?;
    /**
     * @stability stable
     */
    get mode(): number;
    /**
     * @stability stable
     */
    set mode(value: number);
    /**
     * @stability stable
     */
    resetMode(): void;
    /**
     * @stability stable
     */
    get modeInput(): number | undefined;
    private _sizeBytes?;
    /**
     * @stability stable
     */
    get sizeBytes(): number;
    /**
     * @stability stable
     */
    set sizeBytes(value: number);
    /**
     * @stability stable
     */
    resetSizeBytes(): void;
    /**
     * @stability stable
     */
    get sizeBytesInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface ServiceTaskSpecContainerSpecMountsVolumeOptionsLabels {
    /**
     * Name of the label.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#label Service#label}
     *
     * @stability stable
     */
    readonly label: string;
    /**
     * Value of the label.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#value Service#value}
     *
     * @stability stable
     */
    readonly value: string;
}
export declare function serviceTaskSpecContainerSpecMountsVolumeOptionsLabelsToTerraform(struct?: ServiceTaskSpecContainerSpecMountsVolumeOptionsLabels): any;
/**
 * @stability stable
 */
export interface ServiceTaskSpecContainerSpecMountsVolumeOptions {
    /**
     * Name of the driver to use to create the volume.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#driver_name Service#driver_name}
     *
     * @stability stable
     */
    readonly driverName?: string;
    /**
     * key/value map of driver specific options.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#driver_options Service#driver_options}
     *
     * @stability stable
     */
    readonly driverOptions?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Populate volume with data from the target.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#no_copy Service#no_copy}
     *
     * @stability stable
     */
    readonly noCopy?: boolean | cdktf.IResolvable;
    /**
     * labels block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#labels Service#labels}
     *
     * @stability stable
     */
    readonly labels?: ServiceTaskSpecContainerSpecMountsVolumeOptionsLabels[];
}
export declare function serviceTaskSpecContainerSpecMountsVolumeOptionsToTerraform(struct?: ServiceTaskSpecContainerSpecMountsVolumeOptionsOutputReference | ServiceTaskSpecContainerSpecMountsVolumeOptions): any;
/**
 * @stability stable
 */
export declare class ServiceTaskSpecContainerSpecMountsVolumeOptionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ServiceTaskSpecContainerSpecMountsVolumeOptions | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ServiceTaskSpecContainerSpecMountsVolumeOptions | undefined);
    private _driverName?;
    /**
     * @stability stable
     */
    get driverName(): string;
    /**
     * @stability stable
     */
    set driverName(value: string);
    /**
     * @stability stable
     */
    resetDriverName(): void;
    /**
     * @stability stable
     */
    get driverNameInput(): string | undefined;
    private _driverOptions?;
    /**
     * @stability stable
     */
    get driverOptions(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set driverOptions(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetDriverOptions(): void;
    /**
     * @stability stable
     */
    get driverOptionsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _noCopy?;
    /**
     * @stability stable
     */
    get noCopy(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set noCopy(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetNoCopy(): void;
    /**
     * @stability stable
     */
    get noCopyInput(): boolean | cdktf.IResolvable | undefined;
    private _labels?;
    /**
     * @stability stable
     */
    get labels(): ServiceTaskSpecContainerSpecMountsVolumeOptionsLabels[];
    /**
     * @stability stable
     */
    set labels(value: ServiceTaskSpecContainerSpecMountsVolumeOptionsLabels[]);
    /**
     * @stability stable
     */
    resetLabels(): void;
    /**
     * @stability stable
     */
    get labelsInput(): ServiceTaskSpecContainerSpecMountsVolumeOptionsLabels[] | undefined;
}
/**
 * @stability stable
 */
export interface ServiceTaskSpecContainerSpecMounts {
    /**
     * Whether the mount should be read-only.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#read_only Service#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
    /**
     * Mount source (e.g. a volume name, a host path).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#source Service#source}
     *
     * @stability stable
     */
    readonly source?: string;
    /**
     * Container path.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#target Service#target}
     *
     * @stability stable
     */
    readonly target: string;
    /**
     * The mount type.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#type Service#type}
     *
     * @stability stable
     */
    readonly type: string;
    /**
     * bind_options block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#bind_options Service#bind_options}
     *
     * @stability stable
     */
    readonly bindOptions?: ServiceTaskSpecContainerSpecMountsBindOptions;
    /**
     * tmpfs_options block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#tmpfs_options Service#tmpfs_options}
     *
     * @stability stable
     */
    readonly tmpfsOptions?: ServiceTaskSpecContainerSpecMountsTmpfsOptions;
    /**
     * volume_options block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#volume_options Service#volume_options}
     *
     * @stability stable
     */
    readonly volumeOptions?: ServiceTaskSpecContainerSpecMountsVolumeOptions;
}
export declare function serviceTaskSpecContainerSpecMountsToTerraform(struct?: ServiceTaskSpecContainerSpecMounts): any;
/**
 * @stability stable
 */
export interface ServiceTaskSpecContainerSpecPrivilegesCredentialSpec {
    /**
     * Load credential spec from this file.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#file Service#file}
     *
     * @stability stable
     */
    readonly file?: string;
    /**
     * Load credential spec from this value in the Windows registry.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#registry Service#registry}
     *
     * @stability stable
     */
    readonly registry?: string;
}
export declare function serviceTaskSpecContainerSpecPrivilegesCredentialSpecToTerraform(struct?: ServiceTaskSpecContainerSpecPrivilegesCredentialSpecOutputReference | ServiceTaskSpecContainerSpecPrivilegesCredentialSpec): any;
/**
 * @stability stable
 */
export declare class ServiceTaskSpecContainerSpecPrivilegesCredentialSpecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ServiceTaskSpecContainerSpecPrivilegesCredentialSpec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ServiceTaskSpecContainerSpecPrivilegesCredentialSpec | undefined);
    private _file?;
    /**
     * @stability stable
     */
    get file(): string;
    /**
     * @stability stable
     */
    set file(value: string);
    /**
     * @stability stable
     */
    resetFile(): void;
    /**
     * @stability stable
     */
    get fileInput(): string | undefined;
    private _registry?;
    /**
     * @stability stable
     */
    get registry(): string;
    /**
     * @stability stable
     */
    set registry(value: string);
    /**
     * @stability stable
     */
    resetRegistry(): void;
    /**
     * @stability stable
     */
    get registryInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface ServiceTaskSpecContainerSpecPrivilegesSeLinuxContext {
    /**
     * Disable SELinux.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#disable Service#disable}
     *
     * @stability stable
     */
    readonly disable?: boolean | cdktf.IResolvable;
    /**
     * SELinux level label.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#level Service#level}
     *
     * @stability stable
     */
    readonly level?: string;
    /**
     * SELinux role label.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#role Service#role}
     *
     * @stability stable
     */
    readonly role?: string;
    /**
     * SELinux type label.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#type Service#type}
     *
     * @stability stable
     */
    readonly type?: string;
    /**
     * SELinux user label.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#user Service#user}
     *
     * @stability stable
     */
    readonly user?: string;
}
export declare function serviceTaskSpecContainerSpecPrivilegesSeLinuxContextToTerraform(struct?: ServiceTaskSpecContainerSpecPrivilegesSeLinuxContextOutputReference | ServiceTaskSpecContainerSpecPrivilegesSeLinuxContext): any;
/**
 * @stability stable
 */
export declare class ServiceTaskSpecContainerSpecPrivilegesSeLinuxContextOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ServiceTaskSpecContainerSpecPrivilegesSeLinuxContext | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ServiceTaskSpecContainerSpecPrivilegesSeLinuxContext | undefined);
    private _disable?;
    /**
     * @stability stable
     */
    get disable(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set disable(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetDisable(): void;
    /**
     * @stability stable
     */
    get disableInput(): boolean | cdktf.IResolvable | undefined;
    private _level?;
    /**
     * @stability stable
     */
    get level(): string;
    /**
     * @stability stable
     */
    set level(value: string);
    /**
     * @stability stable
     */
    resetLevel(): void;
    /**
     * @stability stable
     */
    get levelInput(): string | undefined;
    private _role?;
    /**
     * @stability stable
     */
    get role(): string;
    /**
     * @stability stable
     */
    set role(value: string);
    /**
     * @stability stable
     */
    resetRole(): void;
    /**
     * @stability stable
     */
    get roleInput(): string | undefined;
    private _type?;
    /**
     * @stability stable
     */
    get type(): string;
    /**
     * @stability stable
     */
    set type(value: string);
    /**
     * @stability stable
     */
    resetType(): void;
    /**
     * @stability stable
     */
    get typeInput(): string | undefined;
    private _user?;
    /**
     * @stability stable
     */
    get user(): string;
    /**
     * @stability stable
     */
    set user(value: string);
    /**
     * @stability stable
     */
    resetUser(): void;
    /**
     * @stability stable
     */
    get userInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface ServiceTaskSpecContainerSpecPrivileges {
    /**
     * credential_spec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#credential_spec Service#credential_spec}
     *
     * @stability stable
     */
    readonly credentialSpec?: ServiceTaskSpecContainerSpecPrivilegesCredentialSpec;
    /**
     * se_linux_context block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#se_linux_context Service#se_linux_context}
     *
     * @stability stable
     */
    readonly seLinuxContext?: ServiceTaskSpecContainerSpecPrivilegesSeLinuxContext;
}
export declare function serviceTaskSpecContainerSpecPrivilegesToTerraform(struct?: ServiceTaskSpecContainerSpecPrivilegesOutputReference | ServiceTaskSpecContainerSpecPrivileges): any;
/**
 * @stability stable
 */
export declare class ServiceTaskSpecContainerSpecPrivilegesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ServiceTaskSpecContainerSpecPrivileges | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ServiceTaskSpecContainerSpecPrivileges | undefined);
    private _credentialSpec;
    /**
     * @stability stable
     */
    get credentialSpec(): ServiceTaskSpecContainerSpecPrivilegesCredentialSpecOutputReference;
    /**
     * @stability stable
     */
    putCredentialSpec(value: ServiceTaskSpecContainerSpecPrivilegesCredentialSpec): void;
    /**
     * @stability stable
     */
    resetCredentialSpec(): void;
    /**
     * @stability stable
     */
    get credentialSpecInput(): ServiceTaskSpecContainerSpecPrivilegesCredentialSpec | undefined;
    private _seLinuxContext;
    /**
     * @stability stable
     */
    get seLinuxContext(): ServiceTaskSpecContainerSpecPrivilegesSeLinuxContextOutputReference;
    /**
     * @stability stable
     */
    putSeLinuxContext(value: ServiceTaskSpecContainerSpecPrivilegesSeLinuxContext): void;
    /**
     * @stability stable
     */
    resetSeLinuxContext(): void;
    /**
     * @stability stable
     */
    get seLinuxContextInput(): ServiceTaskSpecContainerSpecPrivilegesSeLinuxContext | undefined;
}
/**
 * @stability stable
 */
export interface ServiceTaskSpecContainerSpecSecrets {
    /**
     * Represents the file GID. Defaults to `0`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#file_gid Service#file_gid}
     *
     * @stability stable
     */
    readonly fileGid?: string;
    /**
     * Represents represents the FileMode of the file. Defaults to `0o444`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#file_mode Service#file_mode}
     *
     * @stability stable
     */
    readonly fileMode?: number;
    /**
     * Represents the final filename in the filesystem.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#file_name Service#file_name}
     *
     * @stability stable
     */
    readonly fileName: string;
    /**
     * Represents the file UID. Defaults to `0`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#file_uid Service#file_uid}
     *
     * @stability stable
     */
    readonly fileUid?: string;
    /**
     * ID of the specific secret that we're referencing.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#secret_id Service#secret_id}
     *
     * @stability stable
     */
    readonly secretId: string;
    /**
     * Name of the secret that this references, but this is just provided for lookup/display purposes.
     *
     * The config in the reference will be identified by its ID
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#secret_name Service#secret_name}
     *
     * @stability stable
     */
    readonly secretName?: string;
}
export declare function serviceTaskSpecContainerSpecSecretsToTerraform(struct?: ServiceTaskSpecContainerSpecSecrets): any;
/**
 * @stability stable
 */
export interface ServiceTaskSpecContainerSpec {
    /**
     * Arguments to the command.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#args Service#args}
     *
     * @stability stable
     */
    readonly args?: string[];
    /**
     * The command/entrypoint to be run in the image.
     *
     * According to the [docker cli](https://github.com/docker/cli/blob/v20.10.7/cli/command/service/opts.go#L705) the override of the entrypoint is also passed to the `command` property and there is no `entrypoint` attribute in the `ContainerSpec` of the service.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#command Service#command}
     *
     * @stability stable
     */
    readonly command?: string[];
    /**
     * The working directory for commands to run in.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#dir Service#dir}
     *
     * @stability stable
     */
    readonly dir?: string;
    /**
     * A list of environment variables in the form VAR="value".
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#env Service#env}
     *
     * @stability stable
     */
    readonly env?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * A list of additional groups that the container process will run as.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#groups Service#groups}
     *
     * @stability stable
     */
    readonly groups?: string[];
    /**
     * The hostname to use for the container, as a valid RFC 1123 hostname.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#hostname Service#hostname}
     *
     * @stability stable
     */
    readonly hostname?: string;
    /**
     * The image name to use for the containers of the service, like `nginx:1.17.6`. Also use the data-source or resource of `docker_image` with the `repo_digest` or `docker_registry_image` with the `name` attribute for this, as shown in the examples.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#image Service#image}
     *
     * @stability stable
     */
    readonly image: string;
    /**
     * Isolation technology of the containers running the service. (Windows only). Defaults to `default`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#isolation Service#isolation}
     *
     * @stability stable
     */
    readonly isolation?: string;
    /**
     * Mount the container's root filesystem as read only.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#read_only Service#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
    /**
     * Amount of time to wait for the container to terminate before forcefully removing it (ms|s|m|h).
     *
     * If not specified or '0s' the destroy will not check if all tasks/containers of the service terminate.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#stop_grace_period Service#stop_grace_period}
     *
     * @stability stable
     */
    readonly stopGracePeriod?: string;
    /**
     * Signal to stop the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#stop_signal Service#stop_signal}
     *
     * @stability stable
     */
    readonly stopSignal?: string;
    /**
     * The user inside the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#user Service#user}
     *
     * @stability stable
     */
    readonly user?: string;
    /**
     * configs block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#configs Service#configs}
     *
     * @stability stable
     */
    readonly configs?: ServiceTaskSpecContainerSpecConfigs[];
    /**
     * dns_config block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#dns_config Service#dns_config}
     *
     * @stability stable
     */
    readonly dnsConfig?: ServiceTaskSpecContainerSpecDnsConfig;
    /**
     * healthcheck block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#healthcheck Service#healthcheck}
     *
     * @stability stable
     */
    readonly healthcheck?: ServiceTaskSpecContainerSpecHealthcheck;
    /**
     * hosts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#hosts Service#hosts}
     *
     * @stability stable
     */
    readonly hosts?: ServiceTaskSpecContainerSpecHosts[];
    /**
     * labels block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#labels Service#labels}
     *
     * @stability stable
     */
    readonly labels?: ServiceTaskSpecContainerSpecLabels[];
    /**
     * mounts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#mounts Service#mounts}
     *
     * @stability stable
     */
    readonly mounts?: ServiceTaskSpecContainerSpecMounts[];
    /**
     * privileges block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#privileges Service#privileges}
     *
     * @stability stable
     */
    readonly privileges?: ServiceTaskSpecContainerSpecPrivileges;
    /**
     * secrets block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#secrets Service#secrets}
     *
     * @stability stable
     */
    readonly secrets?: ServiceTaskSpecContainerSpecSecrets[];
}
export declare function serviceTaskSpecContainerSpecToTerraform(struct?: ServiceTaskSpecContainerSpecOutputReference | ServiceTaskSpecContainerSpec): any;
/**
 * @stability stable
 */
export declare class ServiceTaskSpecContainerSpecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ServiceTaskSpecContainerSpec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ServiceTaskSpecContainerSpec | undefined);
    private _args?;
    /**
     * @stability stable
     */
    get args(): string[];
    /**
     * @stability stable
     */
    set args(value: string[]);
    /**
     * @stability stable
     */
    resetArgs(): void;
    /**
     * @stability stable
     */
    get argsInput(): string[] | undefined;
    private _command?;
    /**
     * @stability stable
     */
    get command(): string[];
    /**
     * @stability stable
     */
    set command(value: string[]);
    /**
     * @stability stable
     */
    resetCommand(): void;
    /**
     * @stability stable
     */
    get commandInput(): string[] | undefined;
    private _dir?;
    /**
     * @stability stable
     */
    get dir(): string;
    /**
     * @stability stable
     */
    set dir(value: string);
    /**
     * @stability stable
     */
    resetDir(): void;
    /**
     * @stability stable
     */
    get dirInput(): string | undefined;
    private _env?;
    /**
     * @stability stable
     */
    get env(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set env(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetEnv(): void;
    /**
     * @stability stable
     */
    get envInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _groups?;
    /**
     * @stability stable
     */
    get groups(): string[];
    /**
     * @stability stable
     */
    set groups(value: string[]);
    /**
     * @stability stable
     */
    resetGroups(): void;
    /**
     * @stability stable
     */
    get groupsInput(): string[] | undefined;
    private _hostname?;
    /**
     * @stability stable
     */
    get hostname(): string;
    /**
     * @stability stable
     */
    set hostname(value: string);
    /**
     * @stability stable
     */
    resetHostname(): void;
    /**
     * @stability stable
     */
    get hostnameInput(): string | undefined;
    private _image?;
    /**
     * @stability stable
     */
    get image(): string;
    /**
     * @stability stable
     */
    set image(value: string);
    /**
     * @stability stable
     */
    get imageInput(): string | undefined;
    private _isolation?;
    /**
     * @stability stable
     */
    get isolation(): string;
    /**
     * @stability stable
     */
    set isolation(value: string);
    /**
     * @stability stable
     */
    resetIsolation(): void;
    /**
     * @stability stable
     */
    get isolationInput(): string | undefined;
    private _readOnly?;
    /**
     * @stability stable
     */
    get readOnly(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnly(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnly(): void;
    /**
     * @stability stable
     */
    get readOnlyInput(): boolean | cdktf.IResolvable | undefined;
    private _stopGracePeriod?;
    /**
     * @stability stable
     */
    get stopGracePeriod(): string;
    /**
     * @stability stable
     */
    set stopGracePeriod(value: string);
    /**
     * @stability stable
     */
    resetStopGracePeriod(): void;
    /**
     * @stability stable
     */
    get stopGracePeriodInput(): string | undefined;
    private _stopSignal?;
    /**
     * @stability stable
     */
    get stopSignal(): string;
    /**
     * @stability stable
     */
    set stopSignal(value: string);
    /**
     * @stability stable
     */
    resetStopSignal(): void;
    /**
     * @stability stable
     */
    get stopSignalInput(): string | undefined;
    private _user?;
    /**
     * @stability stable
     */
    get user(): string;
    /**
     * @stability stable
     */
    set user(value: string);
    /**
     * @stability stable
     */
    resetUser(): void;
    /**
     * @stability stable
     */
    get userInput(): string | undefined;
    private _configs?;
    /**
     * @stability stable
     */
    get configs(): ServiceTaskSpecContainerSpecConfigs[];
    /**
     * @stability stable
     */
    set configs(value: ServiceTaskSpecContainerSpecConfigs[]);
    /**
     * @stability stable
     */
    resetConfigs(): void;
    /**
     * @stability stable
     */
    get configsInput(): ServiceTaskSpecContainerSpecConfigs[] | undefined;
    private _dnsConfig;
    /**
     * @stability stable
     */
    get dnsConfig(): ServiceTaskSpecContainerSpecDnsConfigOutputReference;
    /**
     * @stability stable
     */
    putDnsConfig(value: ServiceTaskSpecContainerSpecDnsConfig): void;
    /**
     * @stability stable
     */
    resetDnsConfig(): void;
    /**
     * @stability stable
     */
    get dnsConfigInput(): ServiceTaskSpecContainerSpecDnsConfig | undefined;
    private _healthcheck;
    /**
     * @stability stable
     */
    get healthcheck(): ServiceTaskSpecContainerSpecHealthcheckOutputReference;
    /**
     * @stability stable
     */
    putHealthcheck(value: ServiceTaskSpecContainerSpecHealthcheck): void;
    /**
     * @stability stable
     */
    resetHealthcheck(): void;
    /**
     * @stability stable
     */
    get healthcheckInput(): ServiceTaskSpecContainerSpecHealthcheck | undefined;
    private _hosts?;
    /**
     * @stability stable
     */
    get hosts(): ServiceTaskSpecContainerSpecHosts[];
    /**
     * @stability stable
     */
    set hosts(value: ServiceTaskSpecContainerSpecHosts[]);
    /**
     * @stability stable
     */
    resetHosts(): void;
    /**
     * @stability stable
     */
    get hostsInput(): ServiceTaskSpecContainerSpecHosts[] | undefined;
    private _labels?;
    /**
     * @stability stable
     */
    get labels(): ServiceTaskSpecContainerSpecLabels[];
    /**
     * @stability stable
     */
    set labels(value: ServiceTaskSpecContainerSpecLabels[]);
    /**
     * @stability stable
     */
    resetLabels(): void;
    /**
     * @stability stable
     */
    get labelsInput(): ServiceTaskSpecContainerSpecLabels[] | undefined;
    private _mounts?;
    /**
     * @stability stable
     */
    get mounts(): ServiceTaskSpecContainerSpecMounts[];
    /**
     * @stability stable
     */
    set mounts(value: ServiceTaskSpecContainerSpecMounts[]);
    /**
     * @stability stable
     */
    resetMounts(): void;
    /**
     * @stability stable
     */
    get mountsInput(): ServiceTaskSpecContainerSpecMounts[] | undefined;
    private _privileges;
    /**
     * @stability stable
     */
    get privileges(): ServiceTaskSpecContainerSpecPrivilegesOutputReference;
    /**
     * @stability stable
     */
    putPrivileges(value: ServiceTaskSpecContainerSpecPrivileges): void;
    /**
     * @stability stable
     */
    resetPrivileges(): void;
    /**
     * @stability stable
     */
    get privilegesInput(): ServiceTaskSpecContainerSpecPrivileges | undefined;
    private _secrets?;
    /**
     * @stability stable
     */
    get secrets(): ServiceTaskSpecContainerSpecSecrets[];
    /**
     * @stability stable
     */
    set secrets(value: ServiceTaskSpecContainerSpecSecrets[]);
    /**
     * @stability stable
     */
    resetSecrets(): void;
    /**
     * @stability stable
     */
    get secretsInput(): ServiceTaskSpecContainerSpecSecrets[] | undefined;
}
/**
 * @stability stable
 */
export interface ServiceTaskSpecLogDriver {
    /**
     * The logging driver to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#name Service#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The options for the logging driver.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#options Service#options}
     *
     * @stability stable
     */
    readonly options?: {
        [key: string]: string;
    } | cdktf.IResolvable;
}
export declare function serviceTaskSpecLogDriverToTerraform(struct?: ServiceTaskSpecLogDriverOutputReference | ServiceTaskSpecLogDriver): any;
/**
 * @stability stable
 */
export declare class ServiceTaskSpecLogDriverOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ServiceTaskSpecLogDriver | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ServiceTaskSpecLogDriver | undefined);
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _options?;
    /**
     * @stability stable
     */
    get options(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set options(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetOptions(): void;
    /**
     * @stability stable
     */
    get optionsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
}
/**
 * @stability stable
 */
export interface ServiceTaskSpecPlacementPlatforms {
    /**
     * The architecture, e.g. `amd64`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#architecture Service#architecture}
     *
     * @stability stable
     */
    readonly architecture: string;
    /**
     * The operation system, e.g. `linux`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#os Service#os}
     *
     * @stability stable
     */
    readonly os: string;
}
export declare function serviceTaskSpecPlacementPlatformsToTerraform(struct?: ServiceTaskSpecPlacementPlatforms): any;
/**
 * @stability stable
 */
export interface ServiceTaskSpecPlacement {
    /**
     * An array of constraints. e.g.: `node.role==manager`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#constraints Service#constraints}
     *
     * @stability stable
     */
    readonly constraints?: string[];
    /**
     * Maximum number of replicas for per node (default value is `0`, which is unlimited).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#max_replicas Service#max_replicas}
     *
     * @stability stable
     */
    readonly maxReplicas?: number;
    /**
     * Preferences provide a way to make the scheduler aware of factors such as topology.
     *
     * They are provided in order from highest to lowest precedence, e.g.: spread=node.role.manager
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#prefs Service#prefs}
     *
     * @stability stable
     */
    readonly prefs?: string[];
    /**
     * platforms block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#platforms Service#platforms}
     *
     * @stability stable
     */
    readonly platforms?: ServiceTaskSpecPlacementPlatforms[];
}
export declare function serviceTaskSpecPlacementToTerraform(struct?: ServiceTaskSpecPlacementOutputReference | ServiceTaskSpecPlacement): any;
/**
 * @stability stable
 */
export declare class ServiceTaskSpecPlacementOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ServiceTaskSpecPlacement | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ServiceTaskSpecPlacement | undefined);
    private _constraints?;
    /**
     * @stability stable
     */
    get constraints(): string[];
    /**
     * @stability stable
     */
    set constraints(value: string[]);
    /**
     * @stability stable
     */
    resetConstraints(): void;
    /**
     * @stability stable
     */
    get constraintsInput(): string[] | undefined;
    private _maxReplicas?;
    /**
     * @stability stable
     */
    get maxReplicas(): number;
    /**
     * @stability stable
     */
    set maxReplicas(value: number);
    /**
     * @stability stable
     */
    resetMaxReplicas(): void;
    /**
     * @stability stable
     */
    get maxReplicasInput(): number | undefined;
    private _prefs?;
    /**
     * @stability stable
     */
    get prefs(): string[];
    /**
     * @stability stable
     */
    set prefs(value: string[]);
    /**
     * @stability stable
     */
    resetPrefs(): void;
    /**
     * @stability stable
     */
    get prefsInput(): string[] | undefined;
    private _platforms?;
    /**
     * @stability stable
     */
    get platforms(): ServiceTaskSpecPlacementPlatforms[];
    /**
     * @stability stable
     */
    set platforms(value: ServiceTaskSpecPlacementPlatforms[]);
    /**
     * @stability stable
     */
    resetPlatforms(): void;
    /**
     * @stability stable
     */
    get platformsInput(): ServiceTaskSpecPlacementPlatforms[] | undefined;
}
/**
 * @stability stable
 */
export interface ServiceTaskSpecResourcesLimits {
    /**
     * The amounf of memory in bytes the container allocates.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#memory_bytes Service#memory_bytes}
     *
     * @stability stable
     */
    readonly memoryBytes?: number;
    /**
     * CPU shares in units of `1/1e9` (or `10^-9`) of the CPU. Should be at least 1000000.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#nano_cpus Service#nano_cpus}
     *
     * @stability stable
     */
    readonly nanoCpus?: number;
}
export declare function serviceTaskSpecResourcesLimitsToTerraform(struct?: ServiceTaskSpecResourcesLimitsOutputReference | ServiceTaskSpecResourcesLimits): any;
/**
 * @stability stable
 */
export declare class ServiceTaskSpecResourcesLimitsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ServiceTaskSpecResourcesLimits | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ServiceTaskSpecResourcesLimits | undefined);
    private _memoryBytes?;
    /**
     * @stability stable
     */
    get memoryBytes(): number;
    /**
     * @stability stable
     */
    set memoryBytes(value: number);
    /**
     * @stability stable
     */
    resetMemoryBytes(): void;
    /**
     * @stability stable
     */
    get memoryBytesInput(): number | undefined;
    private _nanoCpus?;
    /**
     * @stability stable
     */
    get nanoCpus(): number;
    /**
     * @stability stable
     */
    set nanoCpus(value: number);
    /**
     * @stability stable
     */
    resetNanoCpus(): void;
    /**
     * @stability stable
     */
    get nanoCpusInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface ServiceTaskSpecResourcesReservationGenericResources {
    /**
     * The Integer resources.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#discrete_resources_spec Service#discrete_resources_spec}
     *
     * @stability stable
     */
    readonly discreteResourcesSpec?: string[];
    /**
     * The String resources.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#named_resources_spec Service#named_resources_spec}
     *
     * @stability stable
     */
    readonly namedResourcesSpec?: string[];
}
export declare function serviceTaskSpecResourcesReservationGenericResourcesToTerraform(struct?: ServiceTaskSpecResourcesReservationGenericResourcesOutputReference | ServiceTaskSpecResourcesReservationGenericResources): any;
/**
 * @stability stable
 */
export declare class ServiceTaskSpecResourcesReservationGenericResourcesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ServiceTaskSpecResourcesReservationGenericResources | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ServiceTaskSpecResourcesReservationGenericResources | undefined);
    private _discreteResourcesSpec?;
    /**
     * @stability stable
     */
    get discreteResourcesSpec(): string[];
    /**
     * @stability stable
     */
    set discreteResourcesSpec(value: string[]);
    /**
     * @stability stable
     */
    resetDiscreteResourcesSpec(): void;
    /**
     * @stability stable
     */
    get discreteResourcesSpecInput(): string[] | undefined;
    private _namedResourcesSpec?;
    /**
     * @stability stable
     */
    get namedResourcesSpec(): string[];
    /**
     * @stability stable
     */
    set namedResourcesSpec(value: string[]);
    /**
     * @stability stable
     */
    resetNamedResourcesSpec(): void;
    /**
     * @stability stable
     */
    get namedResourcesSpecInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface ServiceTaskSpecResourcesReservation {
    /**
     * The amounf of memory in bytes the container allocates.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#memory_bytes Service#memory_bytes}
     *
     * @stability stable
     */
    readonly memoryBytes?: number;
    /**
     * CPU shares in units of 1/1e9 (or 10^-9) of the CPU. Should be at least 1000000.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#nano_cpus Service#nano_cpus}
     *
     * @stability stable
     */
    readonly nanoCpus?: number;
    /**
     * generic_resources block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#generic_resources Service#generic_resources}
     *
     * @stability stable
     */
    readonly genericResources?: ServiceTaskSpecResourcesReservationGenericResources;
}
export declare function serviceTaskSpecResourcesReservationToTerraform(struct?: ServiceTaskSpecResourcesReservationOutputReference | ServiceTaskSpecResourcesReservation): any;
/**
 * @stability stable
 */
export declare class ServiceTaskSpecResourcesReservationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ServiceTaskSpecResourcesReservation | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ServiceTaskSpecResourcesReservation | undefined);
    private _memoryBytes?;
    /**
     * @stability stable
     */
    get memoryBytes(): number;
    /**
     * @stability stable
     */
    set memoryBytes(value: number);
    /**
     * @stability stable
     */
    resetMemoryBytes(): void;
    /**
     * @stability stable
     */
    get memoryBytesInput(): number | undefined;
    private _nanoCpus?;
    /**
     * @stability stable
     */
    get nanoCpus(): number;
    /**
     * @stability stable
     */
    set nanoCpus(value: number);
    /**
     * @stability stable
     */
    resetNanoCpus(): void;
    /**
     * @stability stable
     */
    get nanoCpusInput(): number | undefined;
    private _genericResources;
    /**
     * @stability stable
     */
    get genericResources(): ServiceTaskSpecResourcesReservationGenericResourcesOutputReference;
    /**
     * @stability stable
     */
    putGenericResources(value: ServiceTaskSpecResourcesReservationGenericResources): void;
    /**
     * @stability stable
     */
    resetGenericResources(): void;
    /**
     * @stability stable
     */
    get genericResourcesInput(): ServiceTaskSpecResourcesReservationGenericResources | undefined;
}
/**
 * @stability stable
 */
export interface ServiceTaskSpecResources {
    /**
     * limits block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#limits Service#limits}
     *
     * @stability stable
     */
    readonly limits?: ServiceTaskSpecResourcesLimits;
    /**
     * reservation block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#reservation Service#reservation}
     *
     * @stability stable
     */
    readonly reservation?: ServiceTaskSpecResourcesReservation;
}
export declare function serviceTaskSpecResourcesToTerraform(struct?: ServiceTaskSpecResourcesOutputReference | ServiceTaskSpecResources): any;
/**
 * @stability stable
 */
export declare class ServiceTaskSpecResourcesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ServiceTaskSpecResources | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ServiceTaskSpecResources | undefined);
    private _limits;
    /**
     * @stability stable
     */
    get limits(): ServiceTaskSpecResourcesLimitsOutputReference;
    /**
     * @stability stable
     */
    putLimits(value: ServiceTaskSpecResourcesLimits): void;
    /**
     * @stability stable
     */
    resetLimits(): void;
    /**
     * @stability stable
     */
    get limitsInput(): ServiceTaskSpecResourcesLimits | undefined;
    private _reservation;
    /**
     * @stability stable
     */
    get reservation(): ServiceTaskSpecResourcesReservationOutputReference;
    /**
     * @stability stable
     */
    putReservation(value: ServiceTaskSpecResourcesReservation): void;
    /**
     * @stability stable
     */
    resetReservation(): void;
    /**
     * @stability stable
     */
    get reservationInput(): ServiceTaskSpecResourcesReservation | undefined;
}
/**
 * @stability stable
 */
export interface ServiceTaskSpecRestartPolicy {
    /**
     * Condition for restart.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#condition Service#condition}
     *
     * @stability stable
     */
    readonly condition?: string;
    /**
     * Delay between restart attempts (ms|s|m|h).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#delay Service#delay}
     *
     * @stability stable
     */
    readonly delay?: string;
    /**
     * Maximum attempts to restart a given container before giving up (default value is `0`, which is ignored).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#max_attempts Service#max_attempts}
     *
     * @stability stable
     */
    readonly maxAttempts?: number;
    /**
     * The time window used to evaluate the restart policy (default value is `0`, which is unbounded) (ms|s|m|h).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#window Service#window}
     *
     * @stability stable
     */
    readonly window?: string;
}
export declare function serviceTaskSpecRestartPolicyToTerraform(struct?: ServiceTaskSpecRestartPolicyOutputReference | ServiceTaskSpecRestartPolicy): any;
/**
 * @stability stable
 */
export declare class ServiceTaskSpecRestartPolicyOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ServiceTaskSpecRestartPolicy | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ServiceTaskSpecRestartPolicy | undefined);
    private _condition?;
    /**
     * @stability stable
     */
    get condition(): string;
    /**
     * @stability stable
     */
    set condition(value: string);
    /**
     * @stability stable
     */
    resetCondition(): void;
    /**
     * @stability stable
     */
    get conditionInput(): string | undefined;
    private _delay?;
    /**
     * @stability stable
     */
    get delay(): string;
    /**
     * @stability stable
     */
    set delay(value: string);
    /**
     * @stability stable
     */
    resetDelay(): void;
    /**
     * @stability stable
     */
    get delayInput(): string | undefined;
    private _maxAttempts?;
    /**
     * @stability stable
     */
    get maxAttempts(): number;
    /**
     * @stability stable
     */
    set maxAttempts(value: number);
    /**
     * @stability stable
     */
    resetMaxAttempts(): void;
    /**
     * @stability stable
     */
    get maxAttemptsInput(): number | undefined;
    private _window?;
    /**
     * @stability stable
     */
    get window(): string;
    /**
     * @stability stable
     */
    set window(value: string);
    /**
     * @stability stable
     */
    resetWindow(): void;
    /**
     * @stability stable
     */
    get windowInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface ServiceTaskSpec {
    /**
     * A counter that triggers an update even if no relevant parameters have been changed. See the [spec](https://github.com/docker/swarmkit/blob/master/api/specs.proto#L126).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#force_update Service#force_update}
     *
     * @stability stable
     */
    readonly forceUpdate?: number;
    /**
     * Ids of the networks in which the  container will be put in.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#networks Service#networks}
     *
     * @stability stable
     */
    readonly networks?: string[];
    /**
     * Runtime is the type of runtime specified for the task executor. See the [types](https://github.com/moby/moby/blob/master/api/types/swarm/runtime.go).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#runtime Service#runtime}
     *
     * @stability stable
     */
    readonly runtime?: string;
    /**
     * container_spec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#container_spec Service#container_spec}
     *
     * @stability stable
     */
    readonly containerSpec: ServiceTaskSpecContainerSpec;
    /**
     * log_driver block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#log_driver Service#log_driver}
     *
     * @stability stable
     */
    readonly logDriver?: ServiceTaskSpecLogDriver;
    /**
     * placement block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#placement Service#placement}
     *
     * @stability stable
     */
    readonly placement?: ServiceTaskSpecPlacement;
    /**
     * resources block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#resources Service#resources}
     *
     * @stability stable
     */
    readonly resources?: ServiceTaskSpecResources;
    /**
     * restart_policy block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#restart_policy Service#restart_policy}
     *
     * @stability stable
     */
    readonly restartPolicy?: ServiceTaskSpecRestartPolicy;
}
export declare function serviceTaskSpecToTerraform(struct?: ServiceTaskSpecOutputReference | ServiceTaskSpec): any;
/**
 * @stability stable
 */
export declare class ServiceTaskSpecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ServiceTaskSpec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ServiceTaskSpec | undefined);
    private _forceUpdate?;
    /**
     * @stability stable
     */
    get forceUpdate(): number;
    /**
     * @stability stable
     */
    set forceUpdate(value: number);
    /**
     * @stability stable
     */
    resetForceUpdate(): void;
    /**
     * @stability stable
     */
    get forceUpdateInput(): number | undefined;
    private _networks?;
    /**
     * @stability stable
     */
    get networks(): string[];
    /**
     * @stability stable
     */
    set networks(value: string[]);
    /**
     * @stability stable
     */
    resetNetworks(): void;
    /**
     * @stability stable
     */
    get networksInput(): string[] | undefined;
    private _runtime?;
    /**
     * @stability stable
     */
    get runtime(): string;
    /**
     * @stability stable
     */
    set runtime(value: string);
    /**
     * @stability stable
     */
    resetRuntime(): void;
    /**
     * @stability stable
     */
    get runtimeInput(): string | undefined;
    private _containerSpec;
    /**
     * @stability stable
     */
    get containerSpec(): ServiceTaskSpecContainerSpecOutputReference;
    /**
     * @stability stable
     */
    putContainerSpec(value: ServiceTaskSpecContainerSpec): void;
    /**
     * @stability stable
     */
    get containerSpecInput(): ServiceTaskSpecContainerSpec | undefined;
    private _logDriver;
    /**
     * @stability stable
     */
    get logDriver(): ServiceTaskSpecLogDriverOutputReference;
    /**
     * @stability stable
     */
    putLogDriver(value: ServiceTaskSpecLogDriver): void;
    /**
     * @stability stable
     */
    resetLogDriver(): void;
    /**
     * @stability stable
     */
    get logDriverInput(): ServiceTaskSpecLogDriver | undefined;
    private _placement;
    /**
     * @stability stable
     */
    get placement(): ServiceTaskSpecPlacementOutputReference;
    /**
     * @stability stable
     */
    putPlacement(value: ServiceTaskSpecPlacement): void;
    /**
     * @stability stable
     */
    resetPlacement(): void;
    /**
     * @stability stable
     */
    get placementInput(): ServiceTaskSpecPlacement | undefined;
    private _resources;
    /**
     * @stability stable
     */
    get resources(): ServiceTaskSpecResourcesOutputReference;
    /**
     * @stability stable
     */
    putResources(value: ServiceTaskSpecResources): void;
    /**
     * @stability stable
     */
    resetResources(): void;
    /**
     * @stability stable
     */
    get resourcesInput(): ServiceTaskSpecResources | undefined;
    private _restartPolicy;
    /**
     * @stability stable
     */
    get restartPolicy(): ServiceTaskSpecRestartPolicyOutputReference;
    /**
     * @stability stable
     */
    putRestartPolicy(value: ServiceTaskSpecRestartPolicy): void;
    /**
     * @stability stable
     */
    resetRestartPolicy(): void;
    /**
     * @stability stable
     */
    get restartPolicyInput(): ServiceTaskSpecRestartPolicy | undefined;
}
/**
 * @stability stable
 */
export interface ServiceUpdateConfig {
    /**
     * Delay between task updates (ns|us|ms|s|m|h). Defaults to `0s`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#delay Service#delay}
     *
     * @stability stable
     */
    readonly delay?: string;
    /**
     * Action on update failure: pause | continue | rollback. Defaults to `pause`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#failure_action Service#failure_action}
     *
     * @stability stable
     */
    readonly failureAction?: string;
    /**
     * Failure rate to tolerate during an update. Defaults to `0.0`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#max_failure_ratio Service#max_failure_ratio}
     *
     * @stability stable
     */
    readonly maxFailureRatio?: string;
    /**
     * Duration after each task update to monitor for failure (ns|us|ms|s|m|h). Defaults to `5s`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#monitor Service#monitor}
     *
     * @stability stable
     */
    readonly monitor?: string;
    /**
     * Update order: either 'stop-first' or 'start-first'. Defaults to `stop-first`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#order Service#order}
     *
     * @stability stable
     */
    readonly order?: string;
    /**
     * Maximum number of tasks to be updated in one iteration. Defaults to `1`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#parallelism Service#parallelism}
     *
     * @stability stable
     */
    readonly parallelism?: number;
}
export declare function serviceUpdateConfigToTerraform(struct?: ServiceUpdateConfigOutputReference | ServiceUpdateConfig): any;
/**
 * @stability stable
 */
export declare class ServiceUpdateConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ServiceUpdateConfig | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ServiceUpdateConfig | undefined);
    private _delay?;
    /**
     * @stability stable
     */
    get delay(): string;
    /**
     * @stability stable
     */
    set delay(value: string);
    /**
     * @stability stable
     */
    resetDelay(): void;
    /**
     * @stability stable
     */
    get delayInput(): string | undefined;
    private _failureAction?;
    /**
     * @stability stable
     */
    get failureAction(): string;
    /**
     * @stability stable
     */
    set failureAction(value: string);
    /**
     * @stability stable
     */
    resetFailureAction(): void;
    /**
     * @stability stable
     */
    get failureActionInput(): string | undefined;
    private _maxFailureRatio?;
    /**
     * @stability stable
     */
    get maxFailureRatio(): string;
    /**
     * @stability stable
     */
    set maxFailureRatio(value: string);
    /**
     * @stability stable
     */
    resetMaxFailureRatio(): void;
    /**
     * @stability stable
     */
    get maxFailureRatioInput(): string | undefined;
    private _monitor?;
    /**
     * @stability stable
     */
    get monitor(): string;
    /**
     * @stability stable
     */
    set monitor(value: string);
    /**
     * @stability stable
     */
    resetMonitor(): void;
    /**
     * @stability stable
     */
    get monitorInput(): string | undefined;
    private _order?;
    /**
     * @stability stable
     */
    get order(): string;
    /**
     * @stability stable
     */
    set order(value: string);
    /**
     * @stability stable
     */
    resetOrder(): void;
    /**
     * @stability stable
     */
    get orderInput(): string | undefined;
    private _parallelism?;
    /**
     * @stability stable
     */
    get parallelism(): number;
    /**
     * @stability stable
     */
    set parallelism(value: number);
    /**
     * @stability stable
     */
    resetParallelism(): void;
    /**
     * @stability stable
     */
    get parallelismInput(): number | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/docker/r/service.html docker_service}.
 *
 * @stability stable
 */
export declare class Service extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/docker/r/service.html docker_service} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ServiceConfig);
    /**
     * @stability stable
     */
    get id(): string;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _auth;
    /**
     * @stability stable
     */
    get auth(): ServiceAuthOutputReference;
    /**
     * @stability stable
     */
    putAuth(value: ServiceAuth): void;
    /**
     * @stability stable
     */
    resetAuth(): void;
    /**
     * @stability stable
     */
    get authInput(): ServiceAuth | undefined;
    private _convergeConfig;
    /**
     * @stability stable
     */
    get convergeConfig(): ServiceConvergeConfigOutputReference;
    /**
     * @stability stable
     */
    putConvergeConfig(value: ServiceConvergeConfig): void;
    /**
     * @stability stable
     */
    resetConvergeConfig(): void;
    /**
     * @stability stable
     */
    get convergeConfigInput(): ServiceConvergeConfig | undefined;
    private _endpointSpec;
    /**
     * @stability stable
     */
    get endpointSpec(): ServiceEndpointSpecOutputReference;
    /**
     * @stability stable
     */
    putEndpointSpec(value: ServiceEndpointSpec): void;
    /**
     * @stability stable
     */
    resetEndpointSpec(): void;
    /**
     * @stability stable
     */
    get endpointSpecInput(): ServiceEndpointSpec | undefined;
    private _labels?;
    /**
     * @stability stable
     */
    get labels(): ServiceLabels[];
    /**
     * @stability stable
     */
    set labels(value: ServiceLabels[]);
    /**
     * @stability stable
     */
    resetLabels(): void;
    /**
     * @stability stable
     */
    get labelsInput(): ServiceLabels[] | undefined;
    private _mode;
    /**
     * @stability stable
     */
    get mode(): ServiceModeOutputReference;
    /**
     * @stability stable
     */
    putMode(value: ServiceMode): void;
    /**
     * @stability stable
     */
    resetMode(): void;
    /**
     * @stability stable
     */
    get modeInput(): ServiceMode | undefined;
    private _rollbackConfig;
    /**
     * @stability stable
     */
    get rollbackConfig(): ServiceRollbackConfigOutputReference;
    /**
     * @stability stable
     */
    putRollbackConfig(value: ServiceRollbackConfig): void;
    /**
     * @stability stable
     */
    resetRollbackConfig(): void;
    /**
     * @stability stable
     */
    get rollbackConfigInput(): ServiceRollbackConfig | undefined;
    private _taskSpec;
    /**
     * @stability stable
     */
    get taskSpec(): ServiceTaskSpecOutputReference;
    /**
     * @stability stable
     */
    putTaskSpec(value: ServiceTaskSpec): void;
    /**
     * @stability stable
     */
    get taskSpecInput(): ServiceTaskSpec | undefined;
    private _updateConfig;
    /**
     * @stability stable
     */
    get updateConfig(): ServiceUpdateConfigOutputReference;
    /**
     * @stability stable
     */
    putUpdateConfig(value: ServiceUpdateConfig): void;
    /**
     * @stability stable
     */
    resetUpdateConfig(): void;
    /**
     * @stability stable
     */
    get updateConfigInput(): ServiceUpdateConfig | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
